<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="cs">
<context>
    <name>AlterTableDialog</name>
    <message>
        <location filename="../altertabledialog.cpp" line="27"/>
        <source>Alte&amp;r</source>
        <translation>Alte&amp;r</translation>
    </message>
    <message>
        <location filename="../altertabledialog.cpp" line="47"/>
        <source>Alter Table</source>
        <translation>Alter Table</translation>
    </message>
    <message>
        <location filename="../altertabledialog.cpp" line="73"/>
        <source>Error while renaming table %1: %2.

%3</source>
        <translation>Chyba přejmenování tabulky %1: %2

%3</translation>
    </message>
    <message>
        <location filename="../altertabledialog.cpp" line="81"/>
        <source>Table renamed successfully</source>
        <translation>Tabulka úspěšně přejmenována</translation>
    </message>
    <message>
        <location filename="../altertabledialog.cpp" line="120"/>
        <source>Error while altering table %1: %2.
%3</source>
        <translation>Chyba při změně tabulky %1: %2
%3</translation>
    </message>
    <message>
        <location filename="../altertabledialog.cpp" line="124"/>
        <source>Table altered successfully</source>
        <translation>Tabulka úspěšně změněna</translation>
    </message>
</context>
<context>
    <name>AlterTriggerDialog</name>
    <message>
        <location filename="../altertriggerdialog.cpp" line="23"/>
        <source>&amp;Alter</source>
        <translation>&amp;Alter</translation>
    </message>
    <message>
        <location filename="../altertriggerdialog.cpp" line="31"/>
        <source>Cannot get trigger from the database.</source>
        <translation>Nelze získat trigger z databáze.</translation>
    </message>
    <message>
        <location filename="../altertriggerdialog.cpp" line="51"/>
        <source>Cannot drop trigger: %1.

%2</source>
        <translation>Nelze smazat trigger: %1.

%2</translation>
    </message>
    <message>
        <location filename="../altertriggerdialog.cpp" line="60"/>
        <source>Error while creating trigger: %2.

%3</source>
        <translation>Chyba při vytváření triggeru: %2.

%3</translation>
    </message>
    <message>
        <location filename="../altertriggerdialog.cpp" line="63"/>
        <source>Trigger created successfully</source>
        <translation>Trigger úspěšne vytvořen</translation>
    </message>
</context>
<context>
    <name>AlterViewDialog</name>
    <message>
        <location filename="../alterviewdialog.cpp" line="41"/>
        <source>Alter View</source>
        <translation>Alter View</translation>
    </message>
    <message>
        <location filename="../alterviewdialog.cpp" line="59"/>
        <source>Error while altering view (drop phase): %2.

%3</source>
        <translation type="obsolete">Chyba při změně pohledu (fáze drop): %2.

%3</translation>
    </message>
    <message>
        <location filename="../alterviewdialog.cpp" line="75"/>
        <source>View altered successfully</source>
        <translation>Pohled úspěšně změněn</translation>
    </message>
    <message>
        <location filename="../alterviewdialog.cpp" line="59"/>
        <source>Error while altering view (drop phase): %1.

%2</source>
        <translation>Chyba při změně pohledu (fáze drop): %1.

%2</translation>
    </message>
    <message>
        <location filename="../alterviewdialog.cpp" line="71"/>
        <source>Error while altering view: %1.

%2</source>
        <translation>Chyba při změně pohledu: %1.

%2</translation>
    </message>
</context>
<context>
    <name>AnalyzeDialog</name>
    <message>
        <location filename="../analyzedialog.ui" line="13"/>
        <source>Analyze Database</source>
        <translation>Analýza Databáze</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="25"/>
        <source>Compute Statistics for Selected Tables</source>
        <translation>Výpočet Statistik Vybraných Tabulek</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="44"/>
        <source>&amp;Compute</source>
        <translation>&amp;Výpočet</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="77"/>
        <source>Compute All Statistics</source>
        <translation>Výpočet Statistik Všech Objektů</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="89"/>
        <source>Calculate &amp;All</source>
        <translation>Vý&amp;počet Všech</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="109"/>
        <source>Recalculate the statistics for all objects in the DB.</source>
        <translation>Výpočet statistik všech objektů v dané databázi.</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="119"/>
        <source>Drop Statistics</source>
        <translation>Zrušit Statistiky</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="131"/>
        <source>&amp;Drop</source>
        <translation>&amp;Zrušit</translation>
    </message>
    <message>
        <location filename="../analyzedialog.ui" line="151"/>
        <source>&lt;qt&gt;Statistics for all objects in the database will be dropped.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Všechny statistiky budou zahozeny.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>ConstraintsDialog</name>
    <message>
        <location filename="../constraintsdialog.cpp" line="58"/>
        <source>Error while parsing constraints: %1.

%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../constraintsdialog.cpp" line="127"/>
        <source>No action for INSERT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../constraintsdialog.cpp" line="140"/>
        <source>No action for UPDATE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../constraintsdialog.cpp" line="153"/>
        <source>No action for DELETE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../constraintsdialog.cpp" line="163"/>
        <source>Error while creating trigger: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../constraintsdialog.cpp" line="165"/>
        <source>Trigger created successfully</source>
        <translation>Trigger úspěšne vytvořen</translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="13"/>
        <source>Constraints Triggers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="29"/>
        <source>&amp;Insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="110"/>
        <source>&amp;Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="62"/>
        <source>&amp;Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="95"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../constraintsdialog.ui" line="167"/>
        <source>C&amp;reate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CreateIndexDialog</name>
    <message>
        <location filename="../createindexdialog.cpp" line="76"/>
        <source>Error while creating index: %1
%2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.cpp" line="80"/>
        <source>Index created successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="13"/>
        <source>Create Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="32"/>
        <source>Table Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="39"/>
        <source>Index &amp;Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="75"/>
        <source>&amp;Unique?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="104"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="97"/>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="136"/>
        <source>Column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="141"/>
        <source>Use?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="146"/>
        <source>Asc/Desc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createindexdialog.ui" line="164"/>
        <source>C&amp;reate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CreateTableDialog</name>
    <message>
        <location filename="../createtabledialog.cpp" line="23"/>
        <source>Create Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createtabledialog.cpp" line="72"/>
        <source>Error while creating table: %1.

%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createtabledialog.cpp" line="76"/>
        <source>Table created successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createtabledialog.cpp" line="83"/>
        <source>Sqliteman</source>
        <translation type="unfinished">Sqliteman</translation>
    </message>
    <message>
        <location filename="../createtabledialog.cpp" line="85"/>
        <source>The current content of the Advanced SQL editor will be lost.Do you really want to recreate your SQL?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CreateTriggerDialog</name>
    <message>
        <location filename="../createtriggerdialog.cpp" line="46"/>
        <source>Error while creating trigger: %2.

%3</source>
        <translation type="unfinished">Chyba při vytváření triggeru: %2.

%3</translation>
    </message>
    <message>
        <location filename="../createtriggerdialog.cpp" line="49"/>
        <source>Trigger created successfully</source>
        <translation type="unfinished">Trigger úspěšne vytvořen</translation>
    </message>
    <message>
        <location filename="../createtriggerdialog.ui" line="13"/>
        <source>Create Trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createtriggerdialog.ui" line="25"/>
        <source>C&amp;reate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CreateViewDialog</name>
    <message>
        <location filename="../createviewdialog.cpp" line="49"/>
        <source>Error while creating view: %2.

%3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createviewdialog.cpp" line="52"/>
        <source>View created successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createviewdialog.ui" line="13"/>
        <source>Create View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createviewdialog.ui" line="46"/>
        <source>C&amp;reate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createviewdialog.ui" line="78"/>
        <source>&amp;Select Statement (AS)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createviewdialog.ui" line="96"/>
        <source>&amp;Database:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../createviewdialog.ui" line="112"/>
        <source>&amp;View Name:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DataExportDialog</name>
    <message>
        <location filename="../dataexportdialog.cpp" line="34"/>
        <source>Comma Separated Values (CSV)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="35"/>
        <source>HTML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="36"/>
        <source>MS Excel XML (XLS)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="113"/>
        <source>Export Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="114"/>
        <source>Cannot open file %1 for writting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="298"/>
        <source>Comma Separated Value (*.csv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="300"/>
        <source>HTML (*.html)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="302"/>
        <source>MS Excel XML (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="309"/>
        <source>Export to File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="13"/>
        <source>Export Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="118"/>
        <source>File:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="128"/>
        <source>S&amp;earch...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="140"/>
        <source>&amp;Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="158"/>
        <source>Export to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="165"/>
        <source>F&amp;ile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="175"/>
        <source>Cli&amp;pboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="37"/>
        <source>SQL inserts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="38"/>
        <source>Python List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="304"/>
        <source>SQL inserts (*.sql)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.cpp" line="306"/>
        <source>Python list (*.py)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="38"/>
        <source>Export Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="50"/>
        <source>If it is checked the table header will be exported with the data too.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="53"/>
        <source>&amp;Export Headers Too</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="63"/>
        <source>Specify the output encoding. UTF-8 is a good choice for most exports.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="70"/>
        <source>E&amp;ncoding:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="80"/>
        <source>&amp;Line End:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataexportdialog.ui" line="90"/>
        <source>You can choose the End of Line style here.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DataViewer</name>
    <message>
        <location filename="../dataviewer.cpp" line="148"/>
        <source>Sqliteman</source>
        <translation>Sqliteman</translation>
    </message>
    <message>
        <location filename="../dataviewer.cpp" line="109"/>
        <source>Are you sure you want to remove all content from this table?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.cpp" line="123"/>
        <source>Export Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.cpp" line="123"/>
        <source>Data export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="13"/>
        <source>Data Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="72"/>
        <source>New Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="77"/>
        <source>Remove Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="82"/>
        <source>Truncate Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="87"/>
        <source>Export Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.cpp" line="151"/>
        <source>There is a pending transaction in progress. That cannot be commited now.
Error: %1
Perform rollback?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="92"/>
        <source>Commit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="95"/>
        <source>Commit the current transaction in the result table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="100"/>
        <source>Rollback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.ui" line="103"/>
        <source>Rollback the current transaction in the result table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dataviewer.cpp" line="43"/>
        <source>There is a pending transaction in progress. Perform commit?

Help:
Yes = commit
No = rollback
Cancel = skip this operation and stay in the current table</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Database</name>
    <message>
        <location filename="../database.cpp" line="20"/>
        <source>SQL Error</source>
        <translation>Chyba SQL</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="28"/>
        <source>Error executing: %1.</source>
        <translation>Chyba při spuštění: %1.</translation>
    </message>
    <message>
        <location filename="../database.cpp" line="46"/>
        <source>Cannot get databases list. %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../database.cpp" line="61"/>
        <source>Error while dropping table %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../database.cpp" line="74"/>
        <source>Error while getting the fileds of %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../database.cpp" line="105"/>
        <source>Error while the list of %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../database.cpp" line="144"/>
        <source>Error while the list of the system catalogue: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../database.cpp" line="156"/>
        <source>Error while dropping the view %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../database.cpp" line="169"/>
        <source>Error while dropping the index %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../database.cpp" line="181"/>
        <source>Unable to open file %1 for writing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../database.cpp" line="193"/>
        <source>Error while exporting SQL: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../database.cpp" line="211"/>
        <source>Error while dropping the trigger %1: %2.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HelpBrowser</name>
    <message>
        <location filename="../helpbrowser.ui" line="13"/>
        <source>Sqliteman Help</source>
        <translation>Sqliteman Nápověda</translation>
    </message>
    <message>
        <location filename="../helpbrowser.ui" line="63"/>
        <source>&amp;Document</source>
        <translation>&amp;Dokument</translation>
    </message>
    <message>
        <location filename="../helpbrowser.ui" line="85"/>
        <source>&amp;Back</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <location filename="../helpbrowser.ui" line="90"/>
        <source>&amp;Forward</source>
        <translation>&amp;Vpřed</translation>
    </message>
    <message>
        <location filename="../helpbrowser.ui" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
</context>
<context>
    <name>LiteManWindow</name>
    <message>
        <location filename="../litemanwindow.cpp" line="133"/>
        <source>&amp;New...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="134"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="137"/>
        <source>&amp;Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="138"/>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="141"/>
        <source>&amp;Recent Databases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="148"/>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="149"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="152"/>
        <source>&amp;About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="155"/>
        <source>&amp;Help Content...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="156"/>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="159"/>
        <source>&amp;SQL Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="160"/>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="169"/>
        <source>&amp;Build Query...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="170"/>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="179"/>
        <source>&amp;Create Table...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="180"/>
        <source>Ctrl+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="183"/>
        <source>&amp;Drop Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="186"/>
        <source>&amp;Alter Table...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="187"/>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="190"/>
        <source>Create &amp;View...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="191"/>
        <source>Ctrl+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="194"/>
        <source>&amp;Drop View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="197"/>
        <source>&amp;Alter View...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="200"/>
        <source>&amp;Create Index...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="203"/>
        <source>&amp;Drop Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="206"/>
        <source>D&amp;escribe Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="209"/>
        <source>&amp;Create Trigger...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="212"/>
        <source>&amp;Alter Trigger...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="215"/>
        <source>&amp;Drop Trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="218"/>
        <source>D&amp;escribe Trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="221"/>
        <source>D&amp;escribe View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="224"/>
        <source>D&amp;escribe Index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="230"/>
        <source>&amp;Analyze Statistics...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="233"/>
        <source>&amp;Vacuum...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="236"/>
        <source>A&amp;ttach Database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="239"/>
        <source>&amp;Detach Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="245"/>
        <source>&amp;Constraint Triggers...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="251"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="260"/>
        <source>&amp;Context</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="263"/>
        <source>&amp;Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="274"/>
        <source>&amp;System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="280"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="372"/>
        <source>New Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="844"/>
        <source>SQLite database (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="392"/>
        <source>Open Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="862"/>
        <source>Unable to open or create file %1. It is probably not a database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="444"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="447"/>
        <source>Sqliteman - SQLite databases made easy

Version %1
(c) 2007 Petr Vanek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="485"/>
        <source>No SQL statement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="508"/>
        <source>Query Error: %1

%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="511"/>
        <source>Query OK
Row(s) returned: %1

%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="529"/>
        <source>SQL File (*.sql)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="598"/>
        <source>Are you sure that you wish to drop the table &quot;%1&quot;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="635"/>
        <source>Are you sure that you wish to drop the view &quot;%1&quot;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="664"/>
        <source>Are you sure that you wish to drop the index &quot;%1&quot;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="817"/>
        <source>Query Error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="819"/>
        <source>Query OK
Row(s) returned: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="849"/>
        <source>Attach Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="850"/>
        <source>Enter a Schema Alias:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="913"/>
        <source>Are you sure that you wish to drop the trigger &quot;%1&quot;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="485"/>
        <source>You are trying to run an undefined SQL query. Hint: select your query in the editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="227"/>
        <source>&amp;Reindex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="145"/>
        <source>&amp;Preferences...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="173"/>
        <source>&amp;Export Schema...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="176"/>
        <source>&amp;Dump Database...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="519"/>
        <source>Export Schema</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="529"/>
        <source>Export Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="543"/>
        <source>The process failed to start. Either the invoked program is missing, or you may have insufficient permissions to invoke the program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="546"/>
        <source>The process crashed some time after starting successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="549"/>
        <source>An error occurred when attempting to write to the process. For example, the process may not be running, or it may have closed its input channel.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="552"/>
        <source>An error occurred when attempting to read from the process. For example, the process may not be running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="555"/>
        <source>An unknown error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="557"/>
        <source>Error creating the dump. Reason: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="560"/>
        <source>Dump written into: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="164"/>
        <source>Object &amp;Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="165"/>
        <source>Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="242"/>
        <source>&amp;Refresh Object Tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../litemanwindow.cpp" line="504"/>
        <source>Duration: %1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="29"/>
        <source>From Locales</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="35"/>
        <source>System Predefined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="13"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="37"/>
        <source>&amp;Look and Feel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="57"/>
        <source>&amp;Recently Used Databases:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="67"/>
        <source>Count of the items in the Recent menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="82"/>
        <source>These features require application restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Select the application look/GUI theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="101"/>
        <source>GUI &amp;Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="111"/>
        <source>Select the application interface language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="118"/>
        <source>GUI &amp;Style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="153"/>
        <source>&amp;Data Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="178"/>
        <source>NULL handling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>Highlight the NULL values in the data result table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="193"/>
        <source>&amp;Use NULL highlighting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>Background color of the NULL value cell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="203"/>
        <source>B&amp;ackground</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>&amp;NULL alias:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>Text to be used as a NULL mark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="223"/>
        <source>{null}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="233"/>
        <source>BLOB handling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="245"/>
        <source>Highlight the BLOB values in the data result table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="248"/>
        <source>&amp;Use BLOB highlighting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="255"/>
        <source>Background color of the BLOB value cell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="258"/>
        <source>Ba&amp;ckground</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="265"/>
        <source>&amp;BLOB alias:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="275"/>
        <source>Text to be used as a BLOB mark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="278"/>
        <source>{blob}</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QueryEditorDialog</name>
    <message>
        <location filename="../queryeditordialog.cpp" line="75"/>
        <source>Create View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="77"/>
        <source>Build Query</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="173"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="174"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="179"/>
        <source>View name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="182"/>
        <source>Table to Query: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="187"/>
        <source>Match all of the following terms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="188"/>
        <source>Match any of the following terms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="192"/>
        <source>More</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="193"/>
        <source>Less</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="216"/>
        <source>Fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="233"/>
        <source>Terms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SqlEditor</name>
    <message>
        <location filename="../sqleditor.cpp" line="34"/>
        <source>Col: %1 Row: %2/%3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="128"/>
        <source>Open SQL Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="162"/>
        <source>SQL file (*.sql);;All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="128"/>
        <source>Cannot open file %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="174"/>
        <source>Save SQL Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="174"/>
        <source>Cannot write into file %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="187"/>
        <source>New File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="188"/>
        <source>All you changes will be lost. Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="202"/>
        <source>Document has been changed. Do you want do save its content?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="13"/>
        <source>SqlEditor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="58"/>
        <source>&amp;Run SQL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="61"/>
        <source>Run SQL (F9)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="64"/>
        <source>F9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="69"/>
        <source>Run &amp;Explain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="72"/>
        <source>Run Explain (F6)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="75"/>
        <source>F6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="80"/>
        <source>&amp;Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="83"/>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="88"/>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="91"/>
        <source>Save (Ctrl+S)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="94"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="99"/>
        <source>&amp;New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="102"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="107"/>
        <source>Save &amp;As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="112"/>
        <source>Create View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.ui" line="115"/>
        <source>Create view from the current select statement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqleditor.cpp" line="201"/>
        <source>Closing SQL Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SqlQueryModel</name>
    <message>
        <location filename="../sqlmodels.cpp" line="158"/>
        <source>NULL value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqlmodels.cpp" line="168"/>
        <source>BLOB value</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SqlTableModel</name>
    <message>
        <location filename="../sqlmodels.cpp" line="43"/>
        <source>NULL value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sqlmodels.cpp" line="55"/>
        <source>BLOB value</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TableEditorDialog</name>
    <message>
        <location filename="../tableeditordialog.ui" line="13"/>
        <source>Create Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="25"/>
        <source>C&amp;reate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="72"/>
        <source>De&amp;sign</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="97"/>
        <source>Table &amp;Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="84"/>
        <source>&amp;Database:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="110"/>
        <source>Co&amp;lumns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="132"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="137"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="142"/>
        <source>Not Null</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="147"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="155"/>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="162"/>
        <source>&amp;Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="199"/>
        <source>Ad&amp;vanced (SQL)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tableeditordialog.ui" line="185"/>
        <source>If you need to use an advanced options&lt;br&gt;go to the &quot;&lt;b&gt;Advanced (SQL)&lt;/b&gt;&quot; tab.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TableTree</name>
    <message>
        <location filename="../tabletree.cpp" line="14"/>
        <source>Database</source>
        <translation>Databáze</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="15"/>
        <source>Tables</source>
        <translation>Tabulky</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="16"/>
        <source>Indexes</source>
        <translation>Indexy</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="18"/>
        <source>Views</source>
        <translation>Pohledy</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="19"/>
        <source>Triggers</source>
        <translation>Triggery</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="20"/>
        <source>System Catalogue</source>
        <translation>Systémový Katalog</translation>
    </message>
    <message>
        <location filename="../tabletree.cpp" line="17"/>
        <source>System Indexes</source>
        <translation>Systémové Indexy</translation>
    </message>
</context>
<context>
    <name>TermEditor</name>
    <message>
        <location filename="../queryeditordialog.cpp" line="41"/>
        <source>Contains</source>
        <translation>Obsahuje</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="41"/>
        <source>Doesn&apos;t contain</source>
        <translation>Neobsahuje</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="41"/>
        <source>Equals</source>
        <translation>Rovná se</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="42"/>
        <source>Not equals</source>
        <translation>Nerovná se</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="42"/>
        <source>Bigger than</source>
        <translation>Větší než</translation>
    </message>
    <message>
        <location filename="../queryeditordialog.cpp" line="42"/>
        <source>Smaller than</source>
        <translation>Menší než</translation>
    </message>
</context>
<context>
    <name>VacuumDialog</name>
    <message>
        <location filename="../vacuumdialog.ui" line="67"/>
        <source>Vacuum Database</source>
        <translation>Vacuum Databáze</translation>
    </message>
    <message>
        <location filename="../vacuumdialog.ui" line="25"/>
        <source>Vacuum the Selected Objects</source>
        <translation>Vacuum Vybraných Objektů</translation>
    </message>
    <message>
        <location filename="../vacuumdialog.ui" line="44"/>
        <source>&amp;Vacuum</source>
        <translation>&amp;Vacuum</translation>
    </message>
    <message>
        <location filename="../vacuumdialog.ui" line="79"/>
        <source>Vacuum &amp;All</source>
        <translation>Vacuum Vš&amp;ech</translation>
    </message>
    <message>
        <location filename="../vacuumdialog.ui" line="99"/>
        <source>Strip unused space from the database.</source>
        <translation>Uvolnit nepoužité místo z databáze.</translation>
    </message>
</context>
</TS>
